check_cov
==================================================

.. currentmodule:: skchange.costs.utils

.. autofunction:: check_cov

.. include:: skchange.costs.utils.check_cov.examples

.. raw:: html

    <div class="clearer"></div>